@@ -1,5 +1,5 @@
 import numpy as np
-from srd import federal, oas, quebec, payroll, assistance, covid, ei, Person, Hhold, Dependent
+from srd import federal, oas, quebec, ontario, payroll, assistance, covid, ei, Person, Hhold, Dependent
 from itertools import product
 import pandas as pd
 from multiprocessing import cpu_count, Pool
@@ -7,26 +7,26 @@ from multiprocessing import cpu_count, Pool
 
 class tax:
     """
-    Classe générale pour le calcul des impôts, contributions et prestations.
+    Classe générale pour le calcul des impôts, cotisations et prestations.
 
     Parameters
     ----------
     year: int
         année pour le calcul
-    prov: str
-        province (pour le moment seulement Québec, par défaut)
     ifed: boolean
-        vrai si calcul de l'impôt fédéral demandé
+        vrai si le calcul de l'impôt fédéral est demandé
     ioas: boolean
-        vrai si calcul des prestations de SV et SRG est demandé
+        vrai si le calcul des prestations de PSV, SRG, Allocation et Allocation au survivant est demandé
     iprov: boolean
-        vrai si calcul de l'impôt provincial est demandé
+        vrai si le calcul de l'impôt provincial est demandé
     ipayroll: boolean
-        vrai si calcul des cotisations sociales est demandé
-    icovid_all: boolean
-        vrai si calcul des mesures d'urgence liées à la covid-19 est demandé (seulement en 2020)
+        vrai si le calcul des cotisations sociales est demandé
+    iass: boolean
+        vrai si le calcul des prestations d'aide sociale est demandé
+    policy: policy
+        instance de la classe *policy* du module *covid*
     """
-    def __init__(self, year, prov='qc', ifed=True, ioas=True, iprov=True,
+    def __init__(self, year, ifed=True, ioas=True, iprov=True,
                  ipayroll=True, iass=True, policy=covid.policy()):
         self.year = year
         self.ifed = ifed
@@ -45,8 +45,8 @@ class tax:
         if ifed:
             self.federal = federal.form(year, policy)
         if iprov:
-            if prov == 'qc':
-                self.prov = quebec.form(year)
+            self.prov = {'qc': quebec.form(year),
+                         'on': ontario.form(year)}
         if ioas:
             self.oas = oas.program(year, self.federal)
         if iass:
@@ -54,9 +54,9 @@ class tax:
 
     def compute(self, hh, n_points=1):
         """
-        Cette fonction transfère des revenus de pensions pour les couples éligibles
+        Cette fonction transfère des revenus de pension pour les couples admissibles
         et retient la solution qui maximise le revenu disponible familial.
-        Si n_points=0, pas de fractionnement des revenus de pensions. Par défaut
+        Si n_points=0, pas de fractionnement des revenus de pension. Par défaut
         (n_points=1), les revenus bruts sont égalisés dans la mesure des transferts
         possibles. Pour n>1, une simulation est faite pour chaque point de la grille.
         À noter que lorsque n augmente, les solutions avec n inférieur (notamment n=0)
@@ -67,12 +67,8 @@ class tax:
         hh: Hhold
             instance de la classe Hhold
         n_points: int
-            nombre de points utilisés pour optimiser le transfert de revenus de
-            pension.
-        Returns
-        -------
-        Hhold
-            instance de la classe Hhold
+            nombre de points utilisés pour optimiser le fractionnement de revenus de
+            pension
         """
         if not hh.elig_split or (n_points == 0):
             self.compute_all(hh)
@@ -159,7 +155,7 @@ class tax:
 
     def compute_oas(self, hh):
         """
-        Calcul des prestations de SV et SRG.
+        Calcul des prestations de PSV, SRG, Allocation et Allocation au survivant.
 
         Parameters
         ----------
@@ -188,7 +184,8 @@ class tax:
         hh: Hhold
             instance de la classe Hhold
         """
-        self.prov.file(hh)
+        self.prov[hh.prov].file(hh)
+
 
     def compute_payroll(self, hh):
         """
@@ -203,8 +200,7 @@ class tax:
 
     def compute_covid(self, hh):
         """
-        Calcul des prestations canadiennes d'urgences (PCU et PCUE)
-        et du programme incitatif pour la rétention des travailleurs essentiels (PIRTE).
+        Calcul de la PCU, de la PCUE et du PIRTE (pour 2020).
 
         Parameters
         ----------
@@ -227,21 +223,22 @@ class tax:
 
     def compute_ass(self, hh):
         """
-        Calcul de l'aide sociale.
+        Calcul des prestations d'aide sociale.
 
         Parameters
         ----------
         hh: Hhold
             instance de la classe Hhold
         """
+        amount = self.ass.apply(hh)
         for p in hh.sp:
-            p.inc_social_ass = self.ass.apply(hh)
+            p.inc_social_ass = amount
 
     def compute_after_tax_inc(self, hh):
         """
         Calcul du revenu après impôt fédéral et provincial.
 
-        Calcul fait au niveau individuel et ensuite rattaché à la personne. Un calcul au niveau du ménage est aussi effectué.
+        Calcul fait au niveau individuel et ensuite rattaché à la personne; le résultat au niveau du ménage est aussi disponible.
         """
         for p in hh.sp:
             after_tax_inc = p.inc_tot
@@ -253,9 +250,9 @@ class tax:
 
     def disp_inc(self, hh):
         """
-        Calcul du revenu disponible après impôt, cotisations (sociale et REER) et aide sociale.
+        Calcul du revenu disponible après impôts, cotisations sociales, épargne (positive ou négative) et prestations.
 
-        Calcul fait au niveau individuel et ensuite rattaché à la personne.
+        Calcul fait au niveau individuel et ensuite rattaché à la personne; le résultat au niveau du ménage est aussi disponible.
 
         """
         self.compute_after_tax_inc(hh)
@@ -265,7 +262,7 @@ class tax:
                 disp_inc -= sum(list(p.payroll.values()))
             if self.iass:
                 disp_inc += p.inc_social_ass
-            disp_inc -= p.con_rrsp
+            disp_inc -= p.con_rrsp + p.con_non_rrsp
             p.disp_inc = disp_inc
 
 
