@@ -4,17 +4,14 @@ module_dir = os.path.dirname(os.path.dirname(__file__))
 
 class template:
     """
-    Programme québécois d'assurance parentale.
+    Régime québécois d'assurance parentale (RQAP).
 
-    Ce gabarit sert pour l'instant à calculer les cotisations au programme québécois d'assurance parentale.
+    Ce gabarit sert pour l'instant à calculer les cotisations au RQAP.
 
     """
-    def __init__(self):
-        add_params_as_attr(self,module_dir+'/qpip/params/parameters_2016.csv')
-        return
     def contrib(self, p, hh):
         """
-        Fonction pour calculer les contributions à l'assurance parentale.
+        Fonction pour calculer les cotisations à l'assurance parentale.
 
         Parameters
         ----------
@@ -26,11 +23,10 @@ class template:
         Returns
         -------
         float
-            Montant de la cotisation à l'assurance parentale (annuelle)
+            Montant de la cotisation à l'assurance parentale (annuelle).
         """
-        if p.inc_work <= self.qualifying_threshold_QPIP:
+        if p.inc_work <= self.qualifying_threshold_QPIP or hh.prov != 'qc':
             p.contrib_qpip = p.contrib_qpip_self = 0
-            return 0
         elif p.inc_earn <= self.max_QPIP_earn:
             p.contrib_qpip = self.rate_QPIP_earn * p.inc_earn
             p.contrib_qpip_self = self.rate_QPIP_self_earn * min(p.inc_self_earn,
@@ -39,5 +35,3 @@ class template:
             p.contrib_qpip = self.rate_QPIP_earn * self.max_QPIP_earn
             p.contrib_qpip_self = 0
         return p.contrib_qpip + p.contrib_qpip_self
-
-
